==> qbs-1.2.0.src.zip: qbs-1.2.0/src/app/shared/qbssettings.h <==
/****************************************************************************
**
** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of the Qt Build Suite.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/
#ifndef QBS_QBS_SETTINGS
#define QBS_QBS_SETTINGS

#include <tools/settings.h>

#include <QSharedPointer>
#include <QStringList>
#include <QVariant>

typedef QSharedPointer<qbs::Settings> SettingsPtr;

inline SettingsPtr qbsSettings(const QString &baseDir)
{
    return SettingsPtr(new qbs::Settings(baseDir));
}

inline QString settingsValueToRepresentation(const QVariant &value)
{
    if (value.type() == QVariant::Bool)
        return QLatin1String(value.toBool() ? "true" : "false");
    return value.toStringList().join(QLatin1String(","));
}

inline QVariant representationToSettingsValue(const QString &representation)
{
    if (representation == QLatin1String("true"))
        return QVariant(true);
    if (representation == QLatin1String("false"))
        return QVariant(false);
    const QStringList list = representation.split(QLatin1Char(','), QString::SkipEmptyParts);
    if (list.count() > 1)
        return list;
    return representation;
}

#endif // Include guard

==> qbs-1.3.1.src.zip: qbs-1.3.1/src/app/shared/qbssettings.h <==
/****************************************************************************
**
** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of the Qt Build Suite.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/
#ifndef QBS_QBS_SETTINGS
#define QBS_QBS_SETTINGS

#include <tools/settings.h>

#include <QStringList>
#include <QVariant>

QString settingsValueToRepresentation(const QVariant &value);
QVariant representationToSettingsValue(const QString &representation);

#endif // Include guard
